@@ -53,11 +53,8 @@ class IdentitySSOAuthentication(authentication.BaseAuthentication):
         user_info = user_info_reply.json()
         email = user_info["user"]["email"]
         user, _ = User.objects.get_or_create(
-            email__iexact=email,
-            defaults={
-                'username': email,
-                'email': email
-            })
+            email__iexact=email, defaults={"username": email, "email": email}
+        )
         request.session["email"] = user.email
         return (user, None)
 
@@ -90,10 +87,7 @@ class IdentityAPIKeyAuthentication(authentication.BaseAuthentication):
         user_info = user_info_reply.json()
         email = user_info["user"]["email"]
         user, _ = User.objects.get_or_create(
-            email__iexact=email,
-            defaults={
-                'username': email,
-                'email': email
-            })
+            email__iexact=email, defaults={"username": email, "email": email}
+        )
         request.session["email"] = user.email
         return (user, None)
