@@ -14,6 +14,9 @@ import requests
 from django.conf import settings
 from django.http import HttpResponseRedirect, HttpResponse, HttpResponseBadRequest
 
+import logging
+logger = logging.getLogger(__name__)
+
 
 def include_auth_urls():
     return include([path(r"login/", login), path(r"logout/", logout)])
@@ -132,10 +135,14 @@ def delete_all_unexpired_sessions_for_user(user):
     :param user:
     :return:
     """
+    logger.info(f"clearing sessions for user {user.email}, {user.id}")
     all_sessions = Session.objects.filter(expire_date__gte=now())
     user_sessions = [
         session.pk
         for session in all_sessions
         if str(user.pk) == session.get_decoded().get("_auth_user_id")
     ]
-    Session.objects.filter(pk__in=user_sessions).delete()
+    logger.debug(f"found {len(user_sessions)} user sessions")
+    count, sessions_deleted = Session.objects.filter(pk__in=user_sessions).delete()
+    logger.debug(count)
+    logger.debug(sessions_deleted)
\ No newline at end of file
